Skip to main content Module expr Copy item path Source binary_opts Nested message and enum types in BinaryOpts. select_opts Nested message and enum types in SelectOpts. BetweenOpts BinaryOpts Options for vortex.binary CaseWhenOpts Options for vortex.case_when
Encodes num_when_then_pairs and has_else into a single u32 (num_children).
num_children = num_when_then_pairs * 2 + (has_else ? 1 : 0)
has_else = num_children % 2 == 1
num_when_then_pairs = num_children / 2 CastOpts Expr Captures a generic representation of expressions in Vortex.
Expression deserializers can be registered with a Vortex session to handle parsing this into
an in-memory expression for execution. FieldNames GetItemOpts Options for vortex.getitem LikeOpts LiteralOpts Options for vortex.literal PackOpts Options for vortex.pack SelectOpts